Learn R Programming

DNAmotif (version 0.1.1)

DNAmotifs: Generation of motifs from DNA sequences

Description

Using a fasta file as input, the motifs and its corresponding frequencies are generated, considering threshold values (window size and similarity), by making consensus segments via local alignment with gap.

Usage

DNAmotifs(fasta_file, ws, cut_off)

Value

final_results A dataframe of motifs and their corresponding frequncies

Arguments

fasta_file

Sequence file path (.fasta format)

ws

Window size

cut_off

Minimum similarity percentage between the motifs for generating a consensus motif

Examples

Run this code
example_fasta = system.file("exdata/sample.fasta", package = "DNAmotif")
DNAmotifs(fasta_file = example_fasta, ws = 15, cut_off = 0.75)

Run the code above in your browser using DataLab